@@ -17,6 +17,9 @@ class KaruoFlowErrors(Enum):
     ERR_FLOW_CLOSED = 4                     # 流程已结束
     ERR_FLOW_OWNER_INVALID = 5              # 非流程所有人
     ERR_DB_EXCEPTION = 6                    # 数据库异常
+    ERR_FLOW_INFOR_ERROR = 7                # 流程相关信息错误
+    ERR_FLOW_STAGE_ERROR = 8                # 流程阶段错误
+    ERR_FLOW_STAGE_RIGHTS = 9               # 流程阶段权限错误
 
 
     @classmethod
@@ -35,5 +38,11 @@ class KaruoFlowErrors(Enum):
             return "流程的所有者不正确，或许由权限引起"
         elif code == KaruoFlowErrors.ERR_DB_EXCEPTION:
             return "数据库异常"
+        elif code == KaruoFlowErrors.ERR_FLOW_INFOR_ERROR:
+            return "流程相关信息错误"
+        elif code == KaruoFlowErrors.ERR_FLOW_STAGE_ERROR:
+            return "流程阶段错误"
+        elif code == KaruoFlowErrors.ERR_FLOW_STAGE_RIGHTS:
+            return "流程阶段权限错误"
         else:
             return "未捕获错误"
\ No newline at end of file
